#!/usr/bin/python3

from .format import format_string

_msg_types_ncl = {  # message types without colors
    "info": "[info]: ",
    "ok": "[OK]: ",
    "warning": "[WARNING]: ",
    "error": "[ERROR]: "
}

_msg_types = {  # message types with colors
    "info": "[info]: ",
    "ok": format_string("[§dark_green§boldOK§rs]: "),
    "warning": format_string("§yellow§bold[WARNING]: ", auto_rs=False),
    "error": format_string("§red§bold[ERROR]: ", auto_rs=False)
}


class Log:
    def __init__(
        self, log_path: str = None,
        console_out: bool = True,
        console_colored: bool = True,
        file_colored: bool = True
    ):
        self.log_path = log_path
        self.console_out = console_out
        self.console_colored = console_colored
        self.file_colored = file_colored

    def write(self, msg: str, msg_type: str = "info", prefix: str = ""):
        logfile_msg = self.format_msg(msg, msg_type, self.file_colored, prefix) + "\n"

        if self.console_out:
            console_msg = self.format_msg(msg, msg_type, self.console_colored, prefix)

            print(console_msg)

        if self.log_path is not None:
            logfile = open(self.log_path, "a")
            logfile.write(logfile_msg)
            logfile.close()

    def format_msg(self, msg, msg_type: str="info", colored: bool=True, prefix: str=""):
        if colored:
            formatted_msg = _msg_types[msg_type] + msg
            formatted_msg += format_string("§rs")

        else:
            formatted_msg = _msg_types_ncl[msg_type] + msg

        formatted_msg = prefix + formatted_msg

        return formatted_msg

    def read(self):
        if self.log_path is not None:
            log_file = open(self.log_path, "r")
            log_content = log_file.read()
            log_file.close()
            return log_content

        else:
            raise FileNotFoundError("You didn't specify a log path at the log instance definition.")

    def clear(self):
        logfile = open(self.log_path, "w")
        logfile.write("")
        logfile.close()
